==> Bundle-Complete-Catalyst-0.01.tar.gz: Bundle-Complete-Catalyst-0.01/lib/Bundle/Complete/Catalyst.pm <==
package Bundle::Complete::Catalyst;

use warnings;
use strict;

our $VERSION = '0.01';

1;

__END__


=head1 NAME

Bundle::Complete::Catalyst - installs all Catalyst modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Complete::Catalyst'

=head1 CONTENTS

Catalyst

Catalyst::Helper::Controller::Scaffold::HTML::Template

Catalyst::Plugin::FormValidate::Simple::OwnCheck

Catalyst::Engine::Apache

Catalyst::Helper::Controller::Scaffold

Catalyst::Model::CDBI

Catalyst::Plugin::Authentication::LDAP

Catalyst::Plugin::OrderedParams

Catalyst::Plugin::RequireSSL

Catalyst::Plugin::Session::Store::DBI

Catalyst::Plugin::Static::Simple

Catalyst::Plugin::UploadProgress

Catalyst::View::HTML::Embperl

Catalyst::Model::DBI

Catalyst::Model::DBI::SQL::LIbrary

Catalyst::Moddel::Proxy

Catalyst::Action::RenderView::ErrorHandler

Catalyst::View::Mason

Catalyst::Model::File

Catalyst::Plugin::Acme::Scramble

Catalyst::Plugin::Upload::Digest

Catalyst::Plugin::Config::YAML

Catalyst::Plugin::CRUD

Catalyst::Plugin::Hooks

Catalyst::Model::DBIC::Schema

Catalyst::Plugin::C3

Catalyst::View::Chart::Strip

Catalyst::Model::DBIC

Catalyst::Model::Gedcom

catalyst::Model::WebService::Lucene

Catalyst::Plugin::ConfigLoader

Catalyst::Plugin::I18N::Request

Catalyst::View::vCard

Catalyst::Plugin::AtomServer

Catalyst::Plugin::AtomServer

Catalyst::Plugin::Authentication::OpenID

Catalyst::Helper::Dojo

Catalyst::Model::Net::Amazon

Catalyst::Plugin::I18N

Catalyst::Plugin::Dumper

Catalyst::Plugin::Markdown

Catalyst::View::Embperl

Catalyst::Plugin::Imager

Catalyst::Model::EVDB

Catalyst::Model::LDAP

Catalyst::Plugin::Session::Store::DBIC

Catalyst::Model

Catalyst::Model::TextLinkAds

Catalyst::Plugin::Authentication::Store::DBIC

Catalyst::Plugin::Authentication::Store::Htpasswd

Catalyst::Plugin::Cache::BerkeleyDB

Catalyst::Plugin::Session::PerUser

Catalyst::Model::Cronolog

Catalyst::Controller::FormBuilder::MultiForm

Catalyst::Engine::Wx

Catalyst::Plugin::Session::Store::File

Catalyst::View::HTML::Template::Compiled

Catalyst::Model::JabberRPC

Catalyst::Model::XMLRPC

Catalyst::Plugin::EmailValid

Catalyst::Plugin::ClamAV

Catalyst::Model::DBIC::Plain

Catalyst::Plugin::Email::Page

Catalyst::Component::InstancePerContext

Catalyst::Controller::View

Catalyst::Plugin::UserAgent

Catalyst::Plugin::Form::Processor

Catalyst::Plugin::FillInForm::ForceUTF8

Catalyst::Plugin::RequestToken

Catalyst::View::GD::Barcode::QRcode

Cayalyst::Action::REST

Catalyst::Log::Log4perl

Catalyst::Plugin::Authentication::Store::LDAP

Catalyst::View::REST::Data::Serializer

Catalyst::Plugin::AutoSession

Catalyst::Plugin::I18N::DBIC

Catalyst::Plugin::Authentication::Credential::Livedoor

Catalyst::Plugin::Session::Store::CDBI

Catalyst::Plugin::Authentication::Store::DBIx::Class

Catalyst::Controller::FormBuilder

Catalyst::Model::CDBI::Plain

Catalyst::View::MicroMason

Catalyst::Plugin::StackTrace

Catalyst::Plugin::Authentication::Credential::BBAuth

Catalyst::View::ClearSilver

Catalyst::Plugin::DateTime

Catalyst::Enzyme

Catalyst::View::GraphViz

Catalyst::View::TT::ControllerLocal

Catalyst::Plugin::Authentication::Credential::HTTP

Catalyst::Component::ACCEPT_CONTEXT

Catalyst::Manual

Catalyst::Model::XML::Feed

Catalyst::Plugin::ConfigLoader::Environment

Catalyst::Plugin::LogWarnings

Catalyst::Plugin::Setenv

Catalyst::Helper::Graphics

Catalyst::Model::YouTube

Catalyst::View::Email

Catalyst::Controller::Rose

Catalyst::Model::RDBO

Catalyst::Model::SWISH

Catalyst::Plugin::Alarm

Catalyst::Plugin::Captcha

Catalyst::Engine::JobQueue::POE

Catalyst::Plugin::AjaxTags

Catalyst::Plugin::MobileAgent

Catalyst::Helper::Doc

Catalyst::Plugin::Charsets::Japanese

Catalyst::Plugin::FormValidator::Simple

Catalyst::Plugin::Session::Manager

Catalyst::View::TT::ForceUTF8

Catalyst::View::XSLT

Catalyst::Plugin::ConfigLoader::Multi

Catalyst::View::TextForge

Catalyst::Plugin::AutoTemplate

Catalyst::Plugin::Authentication::Simple

Catalyst::Plugin::Log::Message

Catalyst::Plugin::Params::Profile

Catalyst::Plugin::Server

Catalyst::Plugin::Authentication::Credential::AOL

Catalyst::Plugin::Authentication::Credential::OpenID

Catalyst::Plugin::JSONRPC

Catalyst::View::Jemplate

Catalyst::View::JSON

Catalyst::Plugin::MobileUserID

Catalyst::Plugin::Authentication::Credential::JugemKey

Catalyst::Action::RenderView

Catalyst::Devel

Catalyst::Engine::Server

Catalyst::Engine::Zeus

Catalyst::Helper::Controller::Scaffold::Mason

Catalyst::Model::CDBI::CRUD

Catalyst::Model::CDBI::Plain

Catalyst::Model::CDBI::Sweet

Catalyst::Model::Jifty::DBI

Catalyst::Model::Plucene

Catalyst::Model::Xapian

Catalyst::Plugin::Authentication::CDBI

Catalyst::Plugin::Authentication::Credential::HTTP::Proxy

Catalyst::Plugin::Browser

Catalyst::Plugin::Cache::FastMmap

Catalyst::Plugin::Compress::Bzip2

Cayalyst::Plugin::Compress::Zlib

Catalyst::Plugin::DefaultEnd

Catalyst::Plugin::Email

Catalyst::Plugin::FillInForm

Catalyst::Plugin::FormValidator

Catalyst::Plugin::Geography

Catalyst::Plugin::Observe

Catalyst::Plugin::PageCache

Catalyst::Plugin::Prototype

Catalyst::Plugin::Scheduler

Catalyst::Plugin::Session

Catalyst::Plugin::Session::FastMmap

Catalyst::Plugin::Singleton

Catalyst::Plugin::Static

Catalyst::Plugin::SubRequest

Catalyst::Plugin::SuperForm

Catalyst::Plugin::Unicode::Encoding

Catalyst::Plugin::Upload::Basename

Catalyst::Plugin::Upload::MD5

Catalyst::Plugin::Upload::MIME

Catalyst::Runtime

catalyst::View::CSS::Squish

Catalyst::View::HTML::Template

Catalyst::View::Petal

Catalyst::View::PSP

Catalyst::View::TT

Catalyst::Plugin::CDBI::Transaction

Catalyst::Plugin::ConfigurablePathTo

Catalyst::Plugin::HTML::Widget::JavaScript

Catalyst::Controller::BindLex

Catalyst::Plugin::Authentication

Catalyst::Plugin::Authentication::Credential::TypeKey

Catalyst::Plugin::Authorization::ACL

Catalyst::Plugin::Authorization::Roles

Catalyst::Plugin::Cache

Catalyst::Plugin::Cache::Store::FastMmap

Catalyst::Plugin::Continuation

Catalyst::Plugin::Images

Catalyst::Plugin::Params::Nested

Catalyst::Plugin::Session

Catalyst::Plugin::Session::Defaults

Catalyst::Plugin::Session::DynamicExpiry

Catalyst::Plugin::Session::State::Cookie

Catalyst::Plugin::Session::State::URI

Catalyst::Plugin::Session::Store::Delegate

Catalyst::Plugin::Session::Store::FastMmap

Catalyst::Plugin::Session::Store::Memcached

Catalyst::Plugin::Snippets

Catalyst::View::TT::FunctionGenerator

Catalyst::Plugin::FormBuilder

Catalyst::Plugin::HashedCookies

Catalyst::Plugin::Log::Handler

Catalyst::Plugin::Session::Flex

Catalyst::View::PHP

Catalyst::Plugin::Authentication::Crededntial::CHAP

Catalyst::Plugin::Authentication::Credential::PAM

Catalyst::Model::Oryx

Catalyst::Model::ISBNDB

Catalyst::Plugin::Config::JSON

Catalyst::Plugin::Crypt::CBC

Catalyst::Plugin::ParseDateTime

Catalyst::Plugin::SanitizeUrl

Catalyst::Plugin::CodeEval

Catalyst::Plugin::Log::Dispatch

Catalyst::Plugin::Redirect

Catalyst::View::SVGTTGraph

Catalyst::Plugin::Cache::FileCache

Catalyst::Plugin::Cache::Memcached

Catalyst::Plugin::HTML::Widget

Catalyst::Plugin::Pluggable

Catalyst::Plugin::Prototype

Catalyst::Plugin::Textile

Catalyst::Plugin::XMLRPC

Catalyst::View::HTML::Template

Catalyst::View::Petal

Catalyst::View::TEST::XML

Catalust::View::REST::YAML

Catalyst::View::TT

Catalyst::Plugin::Authorization::CDBI::GroupToken

Catalyst::View::Seamstress

Catalyst::Plugin::Breadcrumbs

Catalyst::Plugin::CGI::Untaint

Catalyst::Model::DBIS

Catalyst::Model::CacheFunky::Loader

Catalyst::Plugin::Log::Colorful

Catalyst::View::TT::Filters::LazyLoader

Catalyst::Plugin::DateTime::Constructor

Catalyst::Plugin::DBIC::Profiler

Catalyst::Plugin::Session::CGISession

Catalyst::Action::Firebug

Catalyst::Plugin::Account::AutoDiscovery

Catalyst::Plugin::AtomPP

Catalyst::Plugin::Authentication::Basic::Remote

Catalyst::Plugin::Authentication::CDBI::Basic

Catalyst::Plugin::Authentication::Credential::Flickr

Catalyst::Plugin::Authentication::Store::HTTP

Catalyst::Plugin::Email::Japanese

Catalyst::Plugin::Flavour

Catalyst::Plugin::FormValidator::Simple::Auto

Catalyst::Plugin::XSendFile

Catalyst::Plugin::Authentication::Store::RDBO

Catalyst::Helper::View::TTSimple

Catalyst::Model::EmailStore

Catalyst::Plugin::DBIC::Schema::Profiler

Catalyst::View::GD::Barcode

Catalyst::Plugin::MortalForward

Catalyst::Plugin::DBIC::TemplateMaker

Catalyst::Controller::PathArgs

Catalyst::Example::InstantCRUD

Catalyst::Helper::FastCGI::ExternalServer

Catalyst::Model::MogileFS::Client

Catalyst::Plugin::BuildURI

Catalyst::Plugin::Upload::Image::Magick

Catalyst::View::Reproxy

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx at aol.com> 

=head1 COPYRIGHT & LICENSE

Copyright 2007 Kevin W. Henwood, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself, either Perl version 5.8.8 or, at 
your option, any later version of Perl5 you may have.

=cut

1; # End of Bundle::Complete::Catalyst

==> Bundle-Complete-Catalyst-0.02.tar.gz: Bundle-Complete-Catalyst-0.02/lib/Bundle/Complete/Catalyst.pm <==
package Bundle::Complete::Catalyst;

use warnings;
use strict;

our $VERSION = '0.02';

1;

__END__


=head1 NAME

Bundle::Complete::Catalyst - installs all Catalyst modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Complete::Catalyst'

=head1 CONTENTS

Catalyst

Catalyst::Helper::Controller::Scaffold::HTML::Template

Catalyst::Plugin::FormValidator::Simple::OwnCheck

Catalyst::Engine::Apache

Catalyst::Helper::Controller::Scaffold

Catalyst::Model::CDBI

Catalyst::Plugin::Authentication::LDAP

Catalyst::Plugin::OrderedParams

Catalyst::Plugin::RequireSSL

Catalyst::Plugin::Session::Store::DBI

Catalyst::Plugin::Static::Simple

Catalyst::Plugin::UploadProgress

Catalyst::View::HTML::Embperl

Catalyst::Model::DBI

Catalyst::Model::DBI::SQL::LIbrary

Catalyst::Model::Proxy

Catalyst::Action::RenderView::ErrorHandler

Catalyst::View::Mason

Catalyst::Model::File

Catalyst::Plugin::Acme::Scramble

Catalyst::Plugin::Upload::Digest

Catalyst::Plugin::Config::YAML

Catalyst::Plugin::CRUD

Catalyst::Plugin::Hooks

Catalyst::Model::DBIC::Schema

Catalyst::Plugin::C3

Catalyst::View::Chart::Strip

Catalyst::Model::DBIC

Catalyst::Model::Gedcom

Catalyst::Model::WebService::Lucene

Catalyst::Plugin::ConfigLoader

Catalyst::Plugin::I18N::Request

Catalyst::View::vCard

Catalyst::Plugin::AtomServer

Catalyst::Plugin::Authentication::OpenID

Catalyst::Helper::Dojo

Catalyst::Model::Net::Amazon

Catalyst::Plugin::I18N

Catalyst::Plugin::Dumper

Catalyst::Plugin::Markdown

Catalyst::View::Embperl

Catalyst::Plugin::Imager

Catalyst::Model::EVDB

Catalyst::Model::LDAP

Catalyst::Plugin::Session::Store::DBIC

Catalyst::Model

Catalyst::Model::TextLinkAds

Catalyst::Plugin::Authentication::Store::DBIC

Catalyst::Plugin::Authentication::Store::Htpasswd

Catalyst::Plugin::Cache::BerkeleyDB

Catalyst::Plugin::Session::PerUser

Catalyst::Model::Cronolog

Catalyst::Controller::FormBuilder::MultiForm

Catalyst::Engine::Wx

Catalyst::Plugin::Session::Store::File

Catalyst::View::HTML::Template::Compiled

Catalyst::Model::JabberRPC

Catalyst::Model::XMLRPC

Catalyst::Plugin::EmailValid

Catalyst::Plugin::ClamAV

Catalyst::Model::DBIC::Plain

Catalyst::Plugin::Email::Page

Catalyst::Component::InstancePerContext

Catalyst::Controller::View

Catalyst::Plugin::UserAgent

Catalyst::Plugin::Form::Processor

Catalyst::Plugin::FillInForm::ForceUTF8

Catalyst::Plugin::RequestToken

Catalyst::View::GD::Barcode::QRcode

Catalyst::Action::REST

Catalyst::Log::Log4perl

Catalyst::Plugin::Authentication::Store::LDAP

Catalyst::View::REST::Data::Serializer

Catalyst::Plugin::AutoSession

Catalyst::Plugin::I18N::DBIC

Catalyst::Plugin::Authentication::Credential::Livedoor

Catalyst::Plugin::Session::Store::CDBI

Catalyst::Plugin::Authentication::Store::DBIx::Class

Catalyst::Controller::FormBuilder

Catalyst::Model::CDBI::Plain

Catalyst::View::MicroMason

Catalyst::Plugin::StackTrace

Catalyst::Plugin::Authentication::Credential::BBAuth

Catalyst::View::ClearSilver

Catalyst::Plugin::DateTime

Catalyst::Enzyme

Catalyst::View::GraphViz

Catalyst::View::TT::ControllerLocal

Catalyst::Plugin::Authentication::Credential::HTTP

Catalyst::Component::ACCEPT_CONTEXT

Catalyst::Manual

Catalyst::Model::XML::Feed

Catalyst::Plugin::ConfigLoader::Environment

Catalyst::Plugin::LogWarnings

Catalyst::Plugin::Setenv

Catalyst::Helper::Graphics

Catalyst::Model::YouTube

Catalyst::View::Email

Catalyst::Controller::Rose

Catalyst::Model::RDBO

Catalyst::Model::SWISH

Catalyst::Plugin::Alarm

Catalyst::Plugin::Captcha

Catalyst::Engine::JobQueue::POE

Catalyst::Plugin::AjaxTags

Catalyst::Plugin::MobileAgent

Catalyst::Helper::Doc

Catalyst::Plugin::Charsets::Japanese

Catalyst::Plugin::FormValidator::Simple

Catalyst::Plugin::Session::Manager

Catalyst::View::TT::ForceUTF8

Catalyst::View::XSLT

Catalyst::Plugin::ConfigLoader::Multi

Catalyst::View::TextForge

Catalyst::Plugin::AutoTemplate

Catalyst::Plugin::Authentication::Simple

Catalyst::Plugin::Log::Message

Catalyst::Plugin::Params::Profile

Catalyst::Plugin::Server

Catalyst::Plugin::Authentication::Credential::AOL

Catalyst::Plugin::Authentication::Credential::OpenID

Catalyst::Plugin::JSONRPC

Catalyst::View::Jemplate

Catalyst::View::JSON

Catalyst::Plugin::MobileUserID

Catalyst::Plugin::Authentication::Credential::JugemKey

Catalyst::Action::RenderView

Catalyst::Devel

Catalyst::Engine::Server

Catalyst::Engine::Zeus

Catalyst::Helper::Controller::Scaffold::Mason

Catalyst::Model::CDBI::CRUD

Catalyst::Model::CDBI::Plain

Catalyst::Model::CDBI::Sweet

Catalyst::Model::Jifty::DBI

Catalyst::Model::Plucene

Catalyst::Model::Xapian

Catalyst::Plugin::Authentication::CDBI

Catalyst::Plugin::Authentication::Credential::HTTP::Proxy

Catalyst::Plugin::Browser

Catalyst::Plugin::Cache::FastMmap

Catalyst::Plugin::Compress::Bzip2

Catalyst::Plugin::Compress::Zlib

Catalyst::Plugin::DefaultEnd

Catalyst::Plugin::Email

Catalyst::Plugin::FillInForm

Catalyst::Plugin::FormValidator

Catalyst::Plugin::Geography

Catalyst::Plugin::Observe

Catalyst::Plugin::PageCache

Catalyst::Plugin::Prototype

Catalyst::Plugin::Scheduler

Catalyst::Plugin::Session

Catalyst::Plugin::Session::FastMmap

Catalyst::Plugin::Singleton

Catalyst::Plugin::Static

Catalyst::Plugin::SubRequest

Catalyst::Plugin::SuperForm

Catalyst::Plugin::Unicode::Encoding

Catalyst::Plugin::Upload::Basename

Catalyst::Plugin::Upload::MD5

Catalyst::Plugin::Upload::MIME

Catalyst::Runtime

Catalyst::View::CSS::Squish

Catalyst::View::HTML::Template

Catalyst::View::Petal

Catalyst::View::PSP

Catalyst::View::TT

Catalyst::Plugin::CDBI::Transaction

Catalyst::Plugin::ConfigurablePathTo

Catalyst::Plugin::HTML::Widget::JavaScript

Catalyst::Controller::BindLex

Catalyst::Plugin::Authentication

Catalyst::Plugin::Authentication::Credential::TypeKey

Catalyst::Plugin::Authorization::ACL

Catalyst::Plugin::Authorization::Roles

Catalyst::Plugin::Cache

Catalyst::Plugin::Cache::Store::FastMmap

Catalyst::Plugin::Continuation

Catalyst::Plugin::Images

Catalyst::Plugin::Params::Nested

Catalyst::Plugin::Session

Catalyst::Plugin::Session::Defaults

Catalyst::Plugin::Session::DynamicExpiry

Catalyst::Plugin::Session::State::Cookie

Catalyst::Plugin::Session::State::URI

Catalyst::Plugin::Session::Store::Delegate

Catalyst::Plugin::Session::Store::FastMmap

Catalyst::Plugin::Session::Store::Memcached

Catalyst::Plugin::Snippets

Catalyst::View::TT::FunctionGenerator

Catalyst::Plugin::FormBuilder

Catalyst::Plugin::HashedCookies

Catalyst::Plugin::Log::Handler

Catalyst::Plugin::Session::Flex

Catalyst::View::PHP

Catalyst::Plugin::Authentication::Credential::CHAP

Catalyst::Plugin::Authentication::Credential::PAM

Catalyst::Model::Oryx

Catalyst::Model::ISBNDB

Catalyst::Plugin::Config::JSON

Catalyst::Plugin::Crypt::CBC

Catalyst::Plugin::ParseDateTime

Catalyst::Plugin::SanitizeUrl

Catalyst::Plugin::CodeEval

Catalyst::Plugin::Log::Dispatch

Catalyst::Plugin::Redirect

Catalyst::View::SVGTTGraph

Catalyst::Plugin::Cache::FileCache

Catalyst::Plugin::Cache::Memcached

Catalyst::Plugin::HTML::Widget

Catalyst::Plugin::Pluggable

Catalyst::Plugin::Prototype

Catalyst::Plugin::Textile

Catalyst::Plugin::XMLRPC

Catalyst::View::HTML::Template

Catalyst::View::Petal

Catalyst::View::REST::XML

Catalyst::View::REST::YAML

Catalyst::View::TT

Catalyst::Plugin::Authorization::CDBI::GroupToken

Catalyst::View::Seamstress

Catalyst::Plugin::Breadcrumbs

Catalyst::Plugin::CGI::Untaint

Catalyst::Model::DBIS

Catalyst::Model::CacheFunky::Loader

Catalyst::Plugin::Log::Colorful

Catalyst::View::TT::Filters::LazyLoader

Catalyst::Plugin::DateTime::Constructor

Catalyst::Plugin::DBIC::Profiler

Catalyst::Plugin::Session::CGISession

Catalyst::Action::Firebug

Catalyst::Plugin::Account::AutoDiscovery

Catalyst::Plugin::AtomPP

Catalyst::Plugin::Authentication::Basic::Remote

Catalyst::Plugin::Authentication::CDBI::Basic

Catalyst::Plugin::Authentication::Credential::Flickr

Catalyst::Plugin::Authentication::Store::HTTP

Catalyst::Plugin::Email::Japanese

Catalyst::Plugin::Flavour

Catalyst::Plugin::FormValidator::Simple::Auto

Catalyst::Plugin::XSendFile

Catalyst::Plugin::Authentication::Store::RDBO

Catalyst::Helper::View::TTSimple

Catalyst::Model::EmailStore

Catalyst::Plugin::DBIC::Schema::Profiler

Catalyst::View::GD::Barcode

Catalyst::Plugin::MortalForward

Catalyst::Plugin::DBIC::TemplateMaker

Catalyst::Controller::PathArgs

Catalyst::Example::InstantCRUD

Catalyst::Helper::FastCGI::ExternalServer

Catalyst::Model::MogileFS::Client

Catalyst::Plugin::BuildURI

Catalyst::Plugin::Upload::Image::Magick

Catalyst::View::Reproxy

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx at aol.com> 

=head1 COPYRIGHT & LICENSE

Copyright 2007 Kevin W. Henwood, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself, either Perl version 5.8.8 or, at 
your option, any later version of Perl5 you may have.

=cut

1; # End of Bundle::Complete::Catalyst
